import EventHandler from "./EventHandler";
import HighlightPainter from "./HighlightPainter";
import SerializedRange from "./SerializedRange";
interface MarkerConstructorArgs {
    rootElement?: HTMLElement;
    eventHandler?: EventHandler;
    highlightPainter?: HighlightPainter;
}
declare class Marker {
    static normalizeTextCache: any;
    rootElement: Element;
    eventHandler: EventHandler;
    highlightPainter: HighlightPainter;
    state: {
        lastHoverId: string;
        uidToSerializedRange: {
            [key: string]: SerializedRange;
        };
    };
    constructor({ rootElement, highlightPainter, eventHandler, }: MarkerConstructorArgs);
    static clearSelection(): void;
    private static resolveHighlightElements;
    private static normalizeText;
    private static isBlackListedElementNode;
    private static getRealOffset;
    private static unpaintElement;
    private static convertRangeToSelection;
    serializeRange(range: Range, options?: {
        uid?: string;
        charsToKeepForTextBeforeAndTextAfter?: number;
    }): SerializedRange | null;
    paint(serializedRange: SerializedRange): {
        range: Range;
    };
    unpaint(serializedRange: SerializedRange): void;
    deserializeRange(serializedRange: SerializedRange): Range;
    clickListener: (e: Event) => void;
    mouseoverListener: (e: Event) => void;
    addEventListeners(): void;
    removeEventListeners(): void;
    paintHighlights(highlightId: string): void;
    private highlightHovering;
    private getInnerText;
    private getNormalizedInnerText;
    private findLastChildTextNode;
    private findFirstChildTextNode;
    private findPreviousTextNodeInDomTree;
    private findNextTextNodeInDomTree;
    private forwardOffset;
    private backwardOffset;
    private findElementAtOffset;
    private trimRangeSpaces;
    private convertTextNodeToHighlightElement;
    private buildContext;
    private adjustRangeAroundBlackListedElement;
    getSerializedRangeFromUid(uid: string): SerializedRange | null;
}
export default Marker;
export type { MarkerConstructorArgs };
